pub enum Error {
Allocation(Errno),
InvalidId,
Receive(Errno),
Respond(Errno),
}Expand description
Errors regarding to Notify.
Variants
Allocation(Errno)
If the pair cannot be allocated.
InvalidId
If a request has become invalid
Receive(Errno)
If there was an error receiving a request from the kernel.
Respond(Errno)
If there was an error sending a response to a request.